@@ -6,7 +6,7 @@ use List::MoreUtils qw/uniq/;
 use Archer::ConfigLoader;
 use UNIVERSAL::require;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 my $context;
 sub context { $context }
@@ -22,7 +22,7 @@ sub new {
 
     if ( !$$opts{ write_config } ) {
         my $config_loader = Archer::ConfigLoader->new;
-        $self->{ config } = $config_loader->load( $opts->{ config_yaml } );
+        $self->{ config } = $config_loader->load( $opts->{ config_yaml }, $self );
     }
     $self->{ config }->{ global }->{ log } ||= { level => 'debug' };
 
@@ -135,7 +135,7 @@ sub bootstrap {
     return $self;
 }
 
-# TODO: use the log4perl?
+# TODO: use the Log::Dispatch?
 sub log {
     my ( $self, $level, $msg, %opt ) = @_;
 
@@ -166,8 +166,8 @@ my %levels = (
 sub should_log {
     my ( $self, $level ) = @_;
 
-    $levels{ $level }
-        >= $levels{ $self->{ config }->{ global }->{ log }->{ level } };
+    my $setting_level = $self->{config}->{global}->{log}->{level} || 'debug';
+    $levels{ $level } >= $levels{ $setting_level };
 }
 
 1;
