@@ -1,29 +1,37 @@
 package Archer::ConfigLoader;
 use strict;
 use warnings;
-use YAML;
 use Storable;
 use Carp;
 use Kwalify qw(validate); 
 use Path::Class;
 use FindBin;
 
+my $yaml_class;
+if (eval "require YAML::Syck; 1;") {
+    $yaml_class = "YAML::Syck";
+} else {
+    require YAML;
+    $yaml_class = "YAML";
+}
+
 sub new { bless {}, shift }
 
 sub load {
     my ( $self, $stuff, $context ) = @_;
 
-    my $schema_file = file( $FindBin::Bin, 'assets', 'kwalify', 'schema.yaml' );
+    $context->log('debug' => "yaml class: $yaml_class");
 
+    # load
     my $config;
     if (   ( !ref($stuff) && $stuff eq '-' )
         || ( -e $stuff && -r _ ) )
     {
-        $config = YAML::LoadFile($stuff);
+        $config = $yaml_class->can('LoadFile')->($stuff);
         $context->{config_path} = $stuff if $context;
     }
     elsif ( ref($stuff) && ref($stuff) eq 'SCALAR' ) {
-        $config = YAML::Load( ${$stuff} );
+        $config = $yaml_class->can('Load')->( ${$stuff} );
     }
     elsif ( ref($stuff) && ref($stuff) eq 'HASH' ) {
         $config = Storable::dclone($stuff);
@@ -32,7 +40,13 @@ sub load {
         croak "Archer::ConfigLoader->load: $stuff: $!";
     }
 
-    my $res = validate( YAML::LoadFile($schema_file), $config );
+    # setup default value
+    $config->{global}->{assets_path} ||= file( $FindBin::Bin, 'assets')->stringify;
+    $context->log('debug' => "assets path: $config->{global}->{assets_path}");
+
+    # verify
+    my $schema_file = file( $config->{global}->{assets_path}, 'kwalify', 'schema.yaml' );
+    my $res = validate( $yaml_class->can('LoadFile')->($schema_file), $config );
     $context->log( error => $res ) unless $res == 1;
 
     return $config;
